@@ -1,18 +1,17 @@
-# $Id: Cart.pm 85 2005-01-30 03:00:23Z claco $
+# $Id: Cart.pm 149 2005-02-08 23:31:25Z claco $
 package AxKit::XSP::Handel::Cart;
 use strict;
 use warnings;
-use vars qw(@ISA $NS);
-use Apache::AxKit::Language::XSP;
+use vars qw($NS);
+use base 'Apache::AxKit::Language::XSP';
 
-@ISA = ('Apache::AxKit::Language::XSP');
 $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Cart';
 
 {
-    my @context;
+    my @context = 'root';
 
     sub start_document {
-        return '';
+        return "use AxKit::XSP::Handel::Cart;\n";
     };
 
     sub parse_char {
@@ -24,12 +23,22 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Cart';
     sub parse_start {
         my ($e, $tag, %attr) = @_;
 
+        ## cart:new
+        if ($tag eq 'new') {
+
+        };
+
         return '';
     };
 
     sub parse_end {
         my ($e, $tag) = @_;
 
+        ## cart:new
+        if ($tag eq 'new') {
+
+        };
+
         return '';
     };
 };
